function vprime = fr_perso (file,t,C_Taille, save,verbose)
%
% Fr_perso 'abonne' un usager du systeme. Cette fonction crée une 
%   cle privée-signature de cette abonnee depuis sa photo .pgm.oct
%   et la clé publique t, le vecteur de EigenFaces.
%
%		file : nom du fichier pgm.oct à ajouter
%		t    : vecteur EigenFaces
%		C_Taille : ceci est une contrainte (repr X*Y) 
%		vprime : Valeur renvoyee. Clé privée de l'usager.
%
%		DEBUG FLAGS
%		save    : mis a 1 cela sauve de l'environnement
%			   (dans le fichier perso.save)
%		verbose : mis a 1 cela affiche les resultats intermédiares
%
%       Auteur  : Mathieu Deschamps
%                 mathdesc@scourge.fr
%       Date    : 11/02/2004 
%       IUT de Caen -- Licence Pro. M.C.A
%

	cmd=sprintf("load -force %s",file);file
eval(cmd) 
if (dims(1)*dims(2)!=C_Taille) 
			printf("%s: La taille de l'image [%i,%i] et le paramétre \nde la fonction %i doivent correspondre !\n",file,dims(1),dims(2),C_Taille); 
end

yprime=reshape(X,dims(1)*dims(2),1);
yprimec=yprime-ones(dims(1)*dims(2),1)*ncol/2;


if (verbose==1)
 vprime=cov(t,yprimec)
else
 vprime=cov(t,yprimec);
end

if (save==1)
	save "perso.save";
end
printf ("Clé privée générée...\n");
